<?php
/* ========================================================================
 - [modules/admin/item/category.php]
 -      コンテンツカテゴリ
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/08/29] ファイルパスの定数名を変更
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once LIB_DIR.'rkt_manip.php';
require_once LIB_DIR.'rkt_upload.php';
require_once WEBAPP_LIB_DIR.'wap_admin.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_admin
{
    /**
     * 結婚マスターID
     * @var integer
     */
    var $id = null;

    /**
     * データ操作オブジェクト
     * @var object
     */
    var $objmnp = null;

    /**
     * BLOB操作オブジェクト
     * @var object
     */
    var $objfile = null;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN));

        $this->setTemplateFile('admin/item/category.tpl');

        $this->setSafety('id');
        $this->Assign('id', $this->id);

        if ( preg_match('/complete/i',$_SERVER['REQUEST_URI'])){
            $this->Assign('complete', true);
        }

        // データ操作クラスの生成
        $this->objmnp = new RKT_manip($this->objdb, DB_PREFIX.'itm_category');
        $result = $this->do_query();
        if ($result == RKT_MANIP_COMPLETE){
            header('Location: '.HTTP_ACTION.'admin/item/category/complete/');
            exit();
        }

        // 一括更新
        if ($this->do_querys()){
            header('Location: '.HTTP_ACTION.'admin/item/category/complete/');
            exit();
        }

        $this->set_list();
    }

    /**
     * 結婚マスターの設定
     *
     * @access private
     * @return void
     **/
    function set_list()
    {
        $sql = 
            'SELECT '.
                'id,'.
                'sort,'.
                'category '.
            'FROM '.
                DB_PREFIX.'itm_category '.
            'ORDER BY '.
                'sort';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);

        $this->Assign('list', $result);
    }

    /**
     * 表示順番の取得
     *
     * @access private
     * @return interger     データ操作結果
     */
    function get_sort()
    {
        $sql=
            'SELECT '.
                'max(sort) as sort '.
            'FROM '.
                DB_PREFIX.'itm_category ';
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetch(PDO_FETCH_ASSOC);

        return empty($result['sort'])?1:$result['sort']+1;
    }

    /**
     * データ操作設定・実行
     *
     * @access private
     * @return integer  データ操作結果
     */
    function do_query()
    {
        // 新規登録以外の処理
        if (!empty($this->id)){
            $this->objmnp->setCurID($this->id);
        } else {
            $this->objmnp->setValue('sort', $this->get_sort());
        }

        // 更新しない項目名
        $skip = array(
            'sort'
        );
        $this->objmnp->catchInput($skip);

        return $this->objmnp->doManip($this);
    }

    /**
     * 連続データ操作設定・実行
     *
     * @access private
     * @param array $values
     * @return integer  データ操作結果
     */
    function do_querys()
    {
        if (empty($_POST['manips'])){
            return false;
        }

        $this->objfile = RKT_upload::getInstance(BLOB_DRIVER,BLOB_PARAM);

        foreach ($_POST['edits'] as $values){
            $this->update_query($values);
        }
        foreach ($_POST['deletes'] as $values){
            $this->delete_query($values);
        }
        return true;
    }

    /**
     * データ操作設定・実行
     *
     * @access private
     * @param array $values
     * @return integer  データ操作結果
     */
    function update_query($values)
    {
        $id   = RKT_validate::number($values['id'])?$values['id']:0;
        $sort = RKT_validate::number($values['sort'])?$values['sort']:0;
        $id   = $this->objdb->quote($id);
        $sort = $this->objdb->quote($sort);

        $sql =
            'UPDATE '.
                DB_PREFIX.'itm_category '.
            'SET '.
                'sort = '.$sort.' '.
            'WHERE '.
                'id = '.$id;
        return $this->objdb->query($sql);
    }

    /**
     * データ操作設定・実行
     *
     * @access private
     * @param array $values
     * @return integer  データ操作結果
     */
    function delete_query($values)
    {
        $id   = RKT_validate::number($values['delete'])?$values['delete']:0;
        $id   = $this->objdb->quote($id);
        
        if (ITEM_CATEGORY_STATIC == $id){
            return false;
        } elseif (ITEM_CATEGORY_INFO == $id){
            return false;
        } elseif (ITEM_CATEGORY_QUESTION == $id){
            return false;
        }

        $this->delete_item($id);
        $this->delete_fileinfo($id);

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'itm_category '.
            'WHERE '.
                'id = '.$id;
        return $this->objdb->query($sql);
    }

    /**
     * コンテンツ記事の削除
     *
     * @access private
     * @param integer $ref_category
     * @return boolean
     */
    function delete_item($ref_category)
    {
        $sql=
            'SELECT '.
                'id '.
            'FROM '.
                DB_PREFIX.'itm_item '.
            'WHERE '.
                'ref_category = '.$ref_category;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if (empty($result)){
            return false;
        }


        foreach ($result as $value){
            $sql =
                'DELETE FROM '.
                    DB_PREFIX.'itm_select '.
                'WHERE '.
                    'ref_item ='.$value['id'];
            $this->objdb->exec($sql);

            $sql =
                'DELETE FROM '.
                    DB_PREFIX.'itm_option '.
                'WHERE '.
                    'ref_item ='.$value['id'];
            $this->objdb->exec($sql);
        }

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'itm_item '.
            'WHERE '.
                'ref_category = '.$ref_category;
        return $this->objdb->exec($sql);
    }

    /**
     * ファイルの削除
     *
     * @access private
     * @param integer $ref_category
     * @return boolean
     */
    function delete_fileinfo($ref_category)
    {
        $sql=
            'SELECT '.
                'mimetype,'.
                'filename,'.
                'thumbnail '.
            'FROM '.
                DB_PREFIX.'itm_fileinfo '.
            'WHERE '.
                'ref_category = '.$ref_category;
        $stmt = $this->objdb->prepare($sql); 
        $stmt->execute(); 
        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
        if (empty($result)){
            return false;
        }
        
        foreach ($result as $value){
            $this->objfile->unlink(ARCHIVES_DIR.$value['filename']);
            if (preg_match('/image/i', $value['mimetype'])){
                $this->objfile->unlink(ARCHIVES_DIR.$value['thumbnail']);
            }
        } // foreach ($result as $value)

        $sql =
            'DELETE FROM '.
                DB_PREFIX.'itm_fileinfo '.
            'WHERE '.
                'ref_category = '.$ref_category;
        return $this->objdb->exec($sql);
    }
} // webapp
?>
